@@ -8,7 +8,9 @@ from kraken_image_processing.extractors import kraken_image_face_embeddings
 import pkg_resources
 
 
-model = pkg_resources.resource_stream(__name__, 'models/nn4.small2.v1.t7')
+#model = pkg_resources.resource_stream(__name__, 'models/nn4.small2.v1.t7')
+
+model = 'models/nn4.small2.v1.t7'
 
 embedder = cv2.dnn.readNetFromTorch(model)
 
